import cv2
import sys


def showw(message, image):
	cv2.imshow(message, image)
	cv2.waitKey(0)
	cv2.destroyAllWindows()


def showx(message, image):
	cv2.imshow(message, image)
	cv2.waitKey(0)
	cv2.destroyAllWindows()
	sys.exit()


import sys


def printw(*messages):
	acc_string = ""
	for m in messages: acc_string += str(m)+" "
	print(acc_string)
	_ = input()


def printx(*messages):
	acc_string = ""
	for m in messages: acc_string += str(m)+" "
	print(acc_string)
	sys.exit()


